@@ -29,9 +29,14 @@
 // don't include it directly
 
 namespace Rcpp{
-
+	namespace RcppEigen{
+		template <typename T> SEXP eigen_wrap( const T& object ) ;
+	}
+	
 template <typename T> SEXP wrap( const T& object ) ;
 
+template <typename T> class CustomImporter ;
+
 namespace internal{
 	
 	template <typename InputIterator> SEXP range_wrap(InputIterator first, InputIterator last) ;
@@ -245,6 +250,16 @@ inline SEXP range_wrap_dispatch___impl( InputIterator first, InputIterator last,
 		typename ::Rcpp::traits::r_sexptype_needscast<typename T::second_type>() ) ;
 }
 
+template <typename InputIterator, typename T>
+inline SEXP range_wrap_dispatch___impl( InputIterator first, InputIterator last, ::Rcpp::traits::r_type_int64_tag){ 
+	return Rcpp::int64::LongVector<T>( std::distance(first, last), first, last ) ;
+}
+template <typename InputIterator, typename T>
+inline SEXP range_wrap_dispatch___impl( InputIterator first, InputIterator last, ::Rcpp::traits::r_type_uint64_tag){ 
+	return Rcpp::int64::LongVector<T>( std::distance(first, last), first, last ) ;
+}
+
+
 /**
  * Range based wrap implementation that deals with iterators over
  * pair<const string, U> where U is wrappable. This is the kind of 
@@ -615,6 +630,25 @@ inline SEXP wrap_dispatch_importer__impl( const T& object, ::Rcpp::traits::r_typ
 	return x ;
 }
 
+template <typename T, typename elem_type>
+inline SEXP wrap_dispatch_importer_int64( const T& object ){
+	int size = object.size() ;
+	Rcpp::int64::LongVector<elem_type> res(size) ;
+	for( int i=0; i<size; i++){
+		res.set(i, object.get(i) ) ;
+	}
+	return res ;
+}
+
+template <typename T, typename elem_type>
+inline SEXP wrap_dispatch_importer__impl( const T& object, ::Rcpp::traits::r_type_int64_tag ){
+	return wrap_dispatch_importer_int64<T,elem_type>( object ) ;
+}
+template <typename T, typename elem_type>
+inline SEXP wrap_dispatch_importer__impl( const T& object, ::Rcpp::traits::r_type_uint64_tag ){
+	return wrap_dispatch_importer_int64<T,elem_type>( object ) ;
+}
+
 
 template <typename T, typename elem_type>
 inline SEXP wrap_dispatch_importer( const T& object ){
@@ -644,13 +678,24 @@ inline SEXP wrap_dispatch( const T& object, ::Rcpp::traits::wrap_type_primitive_
 	return primitive_wrap( object ) ;
 }
 
+template <typename T>
+inline SEXP wrap_dispatch_eigen( const T& object, ::Rcpp::traits::false_type){
+	return wrap_dispatch_unknown( object, typename ::Rcpp::traits::is_convertible<T,SEXP>::type() ) ;
+}
+
+template <typename T>
+inline SEXP wrap_dispatch_eigen( const T& object, ::Rcpp::traits::true_type){
+	return ::Rcpp::RcppEigen::eigen_wrap( object ) ;
+}
+
+
 /**
  * called when T is wrap_type_unknown_tag and is not an Importer class
  * The next step is to try implicit conversion to SEXP
  */
 template <typename T> 
 inline SEXP wrap_dispatch_unknown_importable( const T& object, ::Rcpp::traits::false_type){
-	return wrap_dispatch_unknown( object, typename ::Rcpp::traits::is_convertible<T,SEXP>::type() ) ;
+	return wrap_dispatch_eigen( object, typename traits::is_eigen_base<T>::type() ) ;
 }
 
 /**
@@ -660,8 +705,7 @@ template <typename T>
 inline SEXP wrap_dispatch_unknown_importable( const T& object, ::Rcpp::traits::true_type){
 	return wrap_dispatch_importer<T,typename T::r_import_type>( object ) ;
 }
- 
- 
+
 /** 
  * This is called by wrap when the wrap_type_traits is wrap_type_unknown_tag
  * 
@@ -671,6 +715,17 @@ template <typename T>
 inline SEXP wrap_dispatch( const T& object, ::Rcpp::traits::wrap_type_unknown_tag ){
 	return wrap_dispatch_unknown_importable( object, typename ::Rcpp::traits::is_importer<T>::type() ) ;
 }
+
+/** 
+ * This is called by wrap when the wrap_type_traits is wrap_type_int64_tag
+ * 
+ * This wraps a single int64
+ */
+template <typename T> 
+inline SEXP wrap_dispatch( const T& object, ::Rcpp::traits::wrap_type_int64_tag ){
+	return Rcpp::int64::new_long<T>( object ) ;
+}
+
 	// }}}
 
 // {{{ wrap a container that is structured in row major order
