@@ -3,7 +3,7 @@
 //
 // r_type_traits.h: Rcpp R/C++ interface class library -- traits to help wrap
 //
-// Copyright (C) 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -59,6 +59,9 @@ struct r_type_pairstring_string_tag{} ;
  */
 struct r_type_pairstring_generic_tag{} ;
 
+struct r_type_int64_tag{} ;
+struct r_type_uint64_tag{} ;
+
 /**
  * R type trait. Helps wrap.
  */
@@ -93,13 +96,6 @@ template<> struct r_type_traits<unsigned int>{ typedef r_type_primitive_tag r_ca
 template<> struct r_type_traits<float>{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits<const char*>{ typedef r_type_string_tag r_category ; } ;
 
-/* long */
-template<> struct r_type_traits<long>{ typedef r_type_primitive_tag r_category ; } ;
-template<> struct r_type_traits< std::pair<const std::string,long> >{ typedef r_type_primitive_tag r_category ; } ;
-
-/* unsigned long */
-template<> struct r_type_traits<unsigned long>{ typedef r_type_primitive_tag r_category ; } ;
-template<> struct r_type_traits< std::pair<const std::string,unsigned long> >{ typedef r_type_primitive_tag r_category ; } ;
 
 /* long double */
 template<> struct r_type_traits<long double>{ typedef r_type_primitive_tag r_category ; } ;
@@ -112,7 +108,7 @@ template<> struct r_type_traits< std::pair<const std::string,short> >{ typedef r
 /* unsigned short */
 template<> struct r_type_traits<unsigned short>{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits< std::pair<const std::string,unsigned short> >{ typedef r_type_primitive_tag r_category ; } ;
-
+                                                    
 /* std::complex<double> */
 template<> struct r_type_traits< std::complex<double> >{ typedef r_type_primitive_tag r_category ; } ;
 template<> struct r_type_traits< std::pair<const std::string,std::complex<double> > >{ typedef r_type_primitive_tag r_category ; } ;
@@ -122,12 +118,27 @@ template<> struct r_type_traits< std::complex<float> >{ typedef r_type_primitive
 template<> struct r_type_traits< std::pair<const std::string,std::complex<float> > >{ typedef r_type_primitive_tag r_category ; } ;
 
 /* long long int */
-#ifdef RCPP_HAS_LONG_LONG_TYPES
-template<> struct r_type_traits<rcpp_long_long_type>{ typedef r_type_primitive_tag r_category ; } ;
-template<> struct r_type_traits< std::pair<const std::string,rcpp_long_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
-template<> struct r_type_traits<rcpp_ulong_long_type>{ typedef r_type_primitive_tag r_category ; } ;
-template<> struct r_type_traits< std::pair<const std::string,rcpp_ulong_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
-#endif
+// #ifdef RCPP_HAS_LONG_LONG_TYPES
+// template<> struct r_type_traits<rcpp_long_long_type>{ typedef r_type_primitive_tag r_category ; } ;
+// template<> struct r_type_traits< std::pair<const std::string,rcpp_long_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
+// template<> struct r_type_traits<rcpp_ulong_long_type>{ typedef r_type_primitive_tag r_category ; } ;
+// template<> struct r_type_traits< std::pair<const std::string,rcpp_ulong_long_type> >{ typedef r_type_primitive_tag r_category ; } ;
+// #endif
+
+// /* long */
+// template<> struct r_type_traits<long>{ typedef r_type_primitive_tag r_category ; } ;
+// template<> struct r_type_traits< std::pair<const std::string,long> >{ typedef r_type_primitive_tag r_category ; } ;
+// 
+// /* unsigned long */
+// template<> struct r_type_traits<unsigned long>{ typedef r_type_primitive_tag r_category ; } ;
+// template<> struct r_type_traits< std::pair<const std::string,unsigned long> >{ typedef r_type_primitive_tag r_category ; } ;
+
+
+
+
+template<> struct r_type_traits<int64_t>{ typedef r_type_int64_tag r_category; } ;
+template<> struct r_type_traits<uint64_t>{ typedef r_type_uint64_tag r_category ; } ;
+
 
 } // traits
 } // Rcpp
