@@ -27,10 +27,6 @@ if( compareVersion( packageDescription( "inline" )[["Version"]], "0.3.4.4" ) < 0
     stop( "Rcpp unit tests need at least the version 0.3.4.4 of inline" )
 }
 
-cppfunction <- function(...){
-    cxxfunction( ..., plugin = "Rcpp" )
-}
-
 if(require("RUnit", quietly = TRUE)) {
 
     is_local <- function(){
