@@ -598,11 +598,14 @@ definitions <- function(){
 	                    int b = input[1] ;
 	                    return List::create(a, b) ;
 	                '
+	            ), 
+	            "factors" = list( 
+	                signature( x = "factor" ), 
+	                '
+	                    StringVector s(x) ;
+	                    return s; 
+	                '
 	            )
-
-                
-                  
-
                   
         )
 
@@ -1246,3 +1249,10 @@ test.ComplexVector.binary.operators <- function(){
     checkEquals( fun(list(TRUE, 4)), list(TRUE, 4L) )
     checkEquals( fun(list(FALSE, -4L)), list(FALSE,-4L) )
 }
+
+test.factors <- function(){
+    fun <-    .rcpp.Vector$factors
+    x <- as.factor( c("c3", "c2", "c1") )
+    y <- fun(x)
+    checkEquals( y, as.character(x) )
+}
