@@ -19,7 +19,7 @@
 
 test.XPtr <- function(){
 	
-	funx <- cppfunction(signature(), '
+	funx <- cxxfunction(signature(), '
 		/* creating a pointer to a vector<int> */
 		std::vector<int>* v = new std::vector<int> ;
 		v->push_back( 1 ) ;
@@ -34,13 +34,13 @@ test.XPtr <- function(){
 		   the external pointer is no more protected by p, but it gets 
 		   protected by being on the R side */
 		return( p ) ;
-	')
+	', plugin = "Rcpp" )
 	xp <- funx()
 	checkEquals( typeof( xp ), "externalptr", 
 		msg = "checking external pointer creation" )
 	
 	# passing the pointer back to C++
-	funx <- cppfunction(signature(x = "externalptr" ), '
+	funx <- cxxfunction(signature(x = "externalptr" ), '
 		/* wrapping x as smart external pointer */
 		/* The SEXP based constructor does not protect the SEXP from 
 		   garbage collection automatically, it is already protected 
@@ -52,20 +52,8 @@ test.XPtr <- function(){
 		
 		/* just return the front of the vector as a SEXP */
 		return( Rcpp::wrap( p->front() ) ) ;
-	')
+	', plugin = "Rcpp" )
 	front <- funx(xp)
 	checkEquals( front, 1L, msg = "check usage of external pointer" )
 }
 
-# this is similar but without inline, the code is included in 
-# the dyn lib. One reason for this is to effectively instanciate one
-# template class Rcpp::XPtr at compile time, so that we know at that
-# point if something is wrong with the code
-test.XPtr.internal <- function(){
-	xp <- .Call( "RcppXPtrExample_create_external_pointer", PACKAGE = "Rcpp" )
-	checkEquals( typeof(xp), "externalptr", msg = "external pointer creation" )
-	
-	back <- .Call( "RcppXPtrExample_get_external_pointer", xp, PACKAGE = "Rcpp" )
-	checkEquals( back, 2L, msg = "external pointer usage" )
-}
-
